summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_descr.py
diff options
context:
space:
mode:
authorSenthil Kumaran <orsenthil@gmail.com>2010-01-08 18:41:40 (GMT)
committerSenthil Kumaran <orsenthil@gmail.com>2010-01-08 18:41:40 (GMT)
commit3ddc435af6873c6304058d7bcbcb19ee4fba7781 (patch)
treec7a03cf0a8b856bae2ebebba55b09f775845c7ca /Lib/test/test_descr.py
parent3194d1454cbc11ec477d83fff3fc749972107d29 (diff)
downloadcpython-3ddc435af6873c6304058d7bcbcb19ee4fba7781.zip
cpython-3ddc435af6873c6304058d7bcbcb19ee4fba7781.tar.gz
cpython-3ddc435af6873c6304058d7bcbcb19ee4fba7781.tar.bz2
Fixing - Issue7026 - RuntimeError: dictionary changed size during iteration. Patch by flox
Diffstat (limited to 'Lib/test/test_descr.py')
-rw-r--r--Lib/test/test_descr.py16
1 files changed, 13 insertions, 3 deletions
diff --git a/Lib/test/test_descr.py b/Lib/test/test_descr.py
index 418337b..a044faf 100644
--- a/Lib/test/test_descr.py
+++ b/Lib/test/test_descr.py
@@ -4598,9 +4598,19 @@ class PTypesLongInitTest(unittest.TestCase):
def test_main():
- # Run all local test cases, with PTypesLongInitTest first.
- test_support.run_unittest(PTypesLongInitTest, OperatorsTest,
- ClassPropertiesAndMethods, DictProxyTests)
+ with warnings.catch_warnings():
+ # Silence Py3k warnings
+ warnings.filterwarnings("ignore", "classic .+ division",
+ DeprecationWarning)
+ warnings.filterwarnings("ignore", "coerce.. not supported",
+ DeprecationWarning)
+ warnings.filterwarnings("ignore", "Overriding __cmp__ ",
+ DeprecationWarning)
+ warnings.filterwarnings("ignore", ".+slice__ has been removed",
+ DeprecationWarning)
+ # Run all local test cases, with PTypesLongInitTest first.
+ test_support.run_unittest(PTypesLongInitTest, OperatorsTest,
+ ClassPropertiesAndMethods, DictProxyTests)
if __name__ == "__main__":
test_main()